@@ -13,11 +13,6 @@ then
     rm /etc/lighttpd/conf.d/cgi.conf
 fi
 
-if [ -f /etc/lighttpd/conf.d/cml.conf ] && cmp -s /etc/defaults/etc/lighttpd/conf.d/cml.conf /etc/lighttpd/conf.d/cml.conf
-then
-    rm /etc/lighttpd/conf.d/cml.conf
-fi
-
 if [ -f /etc/lighttpd/conf.d/debug.conf ] && cmp -s /etc/defaults/etc/lighttpd/conf.d/debug.conf /etc/lighttpd/conf.d/debug.conf
 then
     rm /etc/lighttpd/conf.d/debug.conf
@@ -48,11 +43,6 @@ then
     rm /etc/lighttpd/conf.d/fastcgi.conf
 fi
 
-if [ -f /etc/lighttpd/conf.d/geoip.conf ] && cmp -s /etc/defaults/etc/lighttpd/conf.d/geoip.conf /etc/lighttpd/conf.d/geoip.conf
-then
-    rm /etc/lighttpd/conf.d/geoip.conf
-fi
-
 if [ -f /etc/lighttpd/conf.d/magnet.conf ] && cmp -s /etc/defaults/etc/lighttpd/conf.d/magnet.conf /etc/lighttpd/conf.d/magnet.conf
 then
     rm /etc/lighttpd/conf.d/magnet.conf
@@ -63,11 +53,6 @@ then
     rm /etc/lighttpd/conf.d/mime.conf
 fi
 
-if [ -f /etc/lighttpd/conf.d/mysql_vhost.conf ] && cmp -s /etc/defaults/etc/lighttpd/conf.d/mysql_vhost.conf /etc/lighttpd/conf.d/mysql_vhost.conf
-then
-    rm /etc/lighttpd/conf.d/mysql_vhost.conf
-fi
-
 if [ -f /etc/lighttpd/conf.d/proxy.conf ] && cmp -s /etc/defaults/etc/lighttpd/conf.d/proxy.conf /etc/lighttpd/conf.d/proxy.conf
 then
     rm /etc/lighttpd/conf.d/proxy.conf
@@ -103,11 +88,6 @@ then
     rm /etc/lighttpd/conf.d/status.conf
 fi
 
-if [ -f /etc/lighttpd/conf.d/trigger_b4_dl.conf ] && cmp -s /etc/defaults/etc/lighttpd/conf.d/trigger_b4_dl.conf /etc/lighttpd/conf.d/trigger_b4_dl.conf
-then
-    rm /etc/lighttpd/conf.d/trigger_b4_dl.conf
-fi
-
 if [ -f /etc/lighttpd/conf.d/userdir.conf ] && cmp -s /etc/defaults/etc/lighttpd/conf.d/userdir.conf /etc/lighttpd/conf.d/userdir.conf
 then
     rm /etc/lighttpd/conf.d/userdir.conf
